@@ -12,9 +12,11 @@ do
   echo "cnt$k="`grep -c . $j` >>.cnt.$i
  done
  if [ $i == fr ]; then
-  grep -v '#' conj.src > conj
-  ../../../../bin/dicsort conj
-  mv conj.sorted conj
+  for f in conj accord; do
+   grep -v '#' $f.src > $f
+   ../../../../bin/dicsort $f
+   mv $f.sorted $f
+  done
  fi
  cd ..
 done
