@@ -141,7 +141,7 @@ void obj_arrow(objparm *pm)
     scale(pm->pd,pm->p,2); 
     xx=ii[0]=pm->p[2];yy=ii[1]=pm->p[3];
     l=pm->pd[4];if(l<0) l=0; if(l>200) l=200;
-    dx=(pm->pd[0]-pm->pd[2])*xscale; dy=(pm->pd[1]-pm->pd[3])*yscale;
+    scale2(pm->pd[0]-pm->pd[2],pm->pd[1]-pm->pd[3],&dx,&dy);
     length=sqrt(dx*dx+dy*dy);
     if(length<3 || l<5) goto stem;
     dd[0]=l*dx/length; dd[1]=l*dy/length;
@@ -195,7 +195,7 @@ void obj_parallel(objparm *pm)
     double xv,yv;
     n=pm->pd[6]; if(n<0) return; if(n>256) n=256;
     scale(pm->pd,pm->p,2);
-    xv=pm->pd[4]*xscale; yv=pm->pd[5]*yscale;
+    scale2(pm->pd[4],pm->pd[5],&xv,&yv);
     for(i=0;i<n;i++) {
 	xi=rint(i*xv); yi=rint(i*yv);
 	gdImageLine(image,pm->p[0]+xi,pm->p[1]+yi,pm->p[2]+xi,pm->p[3]+yi,
@@ -301,8 +301,8 @@ void obj_lattice(objparm *pm)
     n1=pm->pd[6];n2=pm->pd[7]; if(n1<0 || n2<0) return;
     if(n1>256) n1=256; if(n2>256) n2=256;
     scale(pm->pd,pm->p,1);
-    xv1=pm->pd[2]*xscale;yv1=pm->pd[3]*yscale;
-    xv2=pm->pd[4]*xscale;yv2=pm->pd[5]*yscale;
+    scale2(pm->pd[2],pm->pd[3],&xv1,&yv1);
+    scale2(pm->pd[4],pm->pd[5],&xv2,&yv2);
     for(i1=0;i1<n1;i1++) {
 	xi1=rint(i1*xv1)+pm->p[0]; yi1=rint(i1*yv1)+pm->p[1];
 	for(i2=0;i2<n2;i2++) {
@@ -501,8 +501,8 @@ void obj_string(objparm *pm)
     else i=1;
     scale(pm->pd,pm->p,1);
     if(*pe=='"') {
-	p2=find_matching(pe+1,'"');
-	if(p2>pe && *(p2+1)==0) {*p2=0; pe++;}
+	p2=strchr(pe+1,'"');
+	if(p2 && *(p2+1)==0) {*p2=0; pe++;}
     }
     if(pm->fill)
       gdImageStringUp(image,*(fonttab[i].fpt),pm->p[0],pm->p[1],pe,
@@ -1013,6 +1013,8 @@ void obj_multicopy(objparm *pm)
     int t;
     /* gestion palette de couleur de l'image a inserer */
     int colorMap[gdMaxColors];
+    int comptmat=0; /* combien de matrices en tout ? */
+    
     for (i=0; (i<gdMaxColors); i++) {
       colorMap[i] = (-1);
     }
@@ -1045,7 +1047,6 @@ void obj_multicopy(objparm *pm)
     /* On recupere les numeros des matrices/vecteurs a faire agir, 
      * s'il n'y en a pas, on les fait toutes agir 
      */
-    int comptmat=0; /* combien de matrices en tout ? */
     for(i=0;i<t && i< JC_NB_MATRICES;i++) {
       if(pm->pd[i]>=1 && pm->pd[i]<=JC_NB_MATRICES){
 	  nummatrices[comptmat] = pm->pd[i];
