@@ -57,7 +57,8 @@ struct cat {
 	{"recreation",	'R'},
 	{"reference",	'Y'},
 	{"document",	'D'},
-	{"popup",	'P'}
+	{"popup",	'P'},
+	{"datamodule",	'M'}
 };
 #define catno (sizeof(cat)/sizeof(cat[0]))
 
