@@ -42,6 +42,9 @@ int nextlist;
 listtype tagbuf[MAX_BLOCKS];
 int nexttag;
 
+struct poolstruct poolbuf[MAX_POOLS];
+int nextpool;
+
 int options;
 #define	op_nocase	(1<<0)
 #define op_deaccent	(1<<1)
@@ -322,8 +325,14 @@ void getparms(void)
     if(wordchr(optionbuf,"alnumonly")!=NULL) options|=op_alnumonly;
     if(wordchr(optionbuf,"onlyalnum")!=NULL) options|=op_alnumonly;
     
-    if(cmd==cmd_comp && wordchr(optionbuf,"debug")!=NULL) cmd=cmd_debug;
-
+    if(cmd==cmd_comp || cmd==cmd_debug) {
+	_getopt("debug",optionbuf);
+	if(optionbuf[0]) {
+	    i=atoi(optionbuf);
+	    if(i>0 || strcmp(optionbuf,"0")==0) debug=i; else debug=1;
+	    if(debug>0) cmd=cmd_debug;
+	}
+    }
     strip_enclosing_par(textbuf);
     strfold(textbuf);
 }
@@ -352,6 +361,7 @@ int main(int argc, char *argv[])
     error1=error2=_error; debug=0;
     wptr=wbuf; wbuf[0]=0;
     getparms();
+    Mnext=Mbuf; Mcnt=0;
     switch(cmd) {
 	case cmd_comp: {
 	    comp:
@@ -372,10 +382,12 @@ int main(int argc, char *argv[])
 	    break;
 	}
 	case cmd_debug: {
+	    if(debug==0) debug=1;
+	    fprintf(stderr,"debug=%d.\n",debug);
 	    for(i=0;i<diccnt;i++)
 	      fprintf(stderr,"Dictionary %d: %s, %d entries.\n",
 		      i+1,dic[i].name,dic[i].len);
-	    debug=1; goto comp;
+	    goto comp;
 	}
 	case cmd_random: {
 	    
