@@ -127,8 +127,14 @@ void p_hint(char *p[MAX_PARM])
 	ex_hint=-1; return;
     }
     snprintf(vbuf_hint,sizeof(vbuf_hint),"%s",p[0]); subst(vbuf_hint);
-    fprintf(outf,"hint=%s\n",executed_str);
-    ex_hint=1;
+    if(strchr(vbuf_hint,'\\')!=NULL) {
+	fprintf(outf,"hint=%s\n",executed_str);
+	ex_hint=1;
+    }
+    else {
+	singlespace(vbuf_hint);
+	fprintf(outf,"hint=!nosubst %s\n\n", vbuf_hint);
+    }
 }
 
 void p_help(char *p[MAX_PARM])
@@ -139,8 +145,14 @@ void p_help(char *p[MAX_PARM])
 	ex_help=-1; return;
     }
     snprintf(vbuf_help,sizeof(vbuf_help),"%s",p[0]); subst(vbuf_help);
-    fprintf(outf,"help=%s\n",executed_str);
-    ex_help=1;
+    if(strchr(vbuf_help,'\\')!=NULL) {
+	fprintf(outf,"help=%s\n",executed_str);
+	ex_help=1;
+    }
+    else {
+	singlespace(vbuf_help);
+	fprintf(outf,"help=!nosubst %s\n\n", vbuf_help);
+    }
 }
 
 void p_solution(char *p[MAX_PARM])
@@ -152,8 +164,14 @@ void p_solution(char *p[MAX_PARM])
     }
     snprintf(vbuf_solution,sizeof(vbuf_solution),"%s",p[0]);
     subst(vbuf_solution);
-    fprintf(outf,"solution=%s\n",executed_str);
-    ex_solution=1;
+    if(strchr(vbuf_solution,'\\')!=NULL) {
+	fprintf(outf,"solution=%s\n",executed_str);
+	ex_solution=1;
+    }
+    else {
+	singlespace(vbuf_solution);
+	fprintf(outf,"solution=!nosubst %s\n\n", vbuf_solution);
+    }
 }
 
 enum {typ_default, typ_num, typ_func, typ_units, typ_text,
