@@ -997,6 +997,20 @@ void calc_replace(char *p)
     strip_trailing_spaces(p);
 }
 
+	/* transforms a string to hexadecimal code, upper-case */
+void calc_hex(char *p)
+{
+    unsigned char *p1, orig[MAX_LINELEN+1];
+    char *p2;
+    char *hex="0123456789ABCDEF";
+    
+    mystrncpy(orig,p,MAX_LINELEN);
+    for(p1=orig, p2=p; *p1 && p2-p<MAX_LINELEN-2; p1++) {
+	*p2++=hex[(*p1>>4)&15]; *p2++=hex[*p1&15];
+    }
+    *p2=0;    
+}
+
 	/* transforms to lower/upper cases */
 void calc_tolower(char *p)
 {
@@ -2095,6 +2109,7 @@ MYFUNCTION calc_routine[]={
       {"getscorerequire",0,	calc_getscorerequire},
       {"getscorestatus",0,	calc_getscorestatus},
       {"getscoreweight",0,	calc_getscoreweight},
+      {"hex",		0,	calc_hex},
       {"htmlmath",	0,	htmlmath},
       {"httpquery",	0,	tohttpquery},
       {"imgrename",	0,	calc_imgrename},
@@ -2219,6 +2234,7 @@ MYFUNCTION calc_routine[]={
       {"system",	0,	calc_sh},
       {"texmath",	0,	texmath},
       {"text",		1,	text},
+      {"tohex",		0,	calc_hex},
       {"tolower",	0,	calc_tolower},
       {"toupper",	0,	calc_toupper},
       {"translate",	1,	calc_translate},
