@@ -143,6 +143,7 @@ char *bgcolor="#E8E8E8";	/* page background color */
 char *bgimg="";			/* page background image file */
 char *pagecss="-theme-";		/* style sheet file */
 char *usecookie="no";		/* whether to send cookies to anon requests */
+char *mail_opt="";		/* !mailto options */
 char nodeip[256]="";		/* ip of cluster node if relevant */
 char temp_log[MAX_FNAME+1];	/* temp log file name */
 	/* 0: low; 1: high; 2: MathML */
@@ -220,6 +221,7 @@ CONFIG_DATA main_config[]={
       {"idle_time2",		1, &idle_time2},
       {"idle_time3",		1, &idle_time3},
       {"insdraw_processor",	0, &insdraw_processor},
+      {"mail_opt",		0, &mail_opt},
       {"manager_https",		1, &manager_https},
       {"manager_site",		0, &manager_site},
       {"maxima_command",	2, &maxima_command},
