@@ -202,7 +202,7 @@ void exec_for(char *p)
 	substit(p2);
 	strip_trailing_spaces(p2);
 	if(*p2==0) goto loop_out;
-	p1=strchr(p2,','); stk->bufpt=p2;
+	p1=strparchr(p2,','); stk->bufpt=p2;
 	if(p1!=NULL) {
 	    *p1=0; stk->list_pt=find_word_start(p1+1);
 	}
@@ -605,7 +605,7 @@ void _httpfollow(char b1[], char *wn, int new)
 		if(s1==NULL) internal_error("exec_href() error.\n");
 		if(ref_mhelp) {
 		    if(strstr(s1,"_mhelp")!=0)
-		      snprintf(st,sizeof(st),"%.10s_mhelp",s1);
+		      snprintf(st,sizeof(st),"%s",s1);
 		    else
 		      snprintf(st,sizeof(st),"%s_mhelp",s1);
 		}
@@ -1574,13 +1574,15 @@ void exec_mailto(char *p)
     if(!trusted_module() || is_class_module) return;
     p1=strchr(p,'\n'); if(p1==NULL) return;
     *p1++=0; p=find_word_start(p);
+    if(*p==0) return;
     p2=strchr(p1,'\n'); if(p2==NULL) return;
     *p2++=0;
     for(pp=p1;*pp;pp++) if(*pp=='"' || *pp=='\n') *pp=' ';
     accessfile(p2,"w","%s/mail.body",tmp_dir);
     wrapexec=1;
-    call_sh("mail -s \" %s \" %s <%s/mail.body; chmod og-rwx %s/mail.body",
-	    p1,p,tmp_dir,tmp_dir);
+    call_sh("mail %s -s \" %s \" %s <%s/mail.body; chmod og-rwx %s/mail.body",
+	    mail_opt, p1,p,tmp_dir,tmp_dir);
+    mail_log(p);
     *p=0;
 }
 
@@ -1683,6 +1685,7 @@ MYFUNCTION exec_routine[]={
       {"goto",		EXEC_JUMP|EXEC_SUBST,	exec_goto},
       {"header",	EXEC_HREF,		exec_header},
       {"headmenu",	EXEC_HREF,		exec_headmenu},
+      {"hex",		EXEC_STRING|EXEC_SUBST|EXEC_USECALC,calc_hex},
       {"homeref",	EXEC_HREF,		exec_homeref},
       {"href",		EXEC_HREF,		exec_href},
       {"htmlbar",	EXEC_HREF,		exec_formbar},
@@ -1806,6 +1809,7 @@ MYFUNCTION exec_routine[]={
       {"texmath",	EXEC_STRING|EXEC_SUBST|EXEC_USECALC,texmath},
       {"text",		EXEC_STRING|EXEC_USECALC,text},
       {"title",		EXEC_HREF,		exec_title},
+      {"tohex",		EXEC_STRING|EXEC_SUBST|EXEC_USECALC,calc_hex},
       {"tolower",	EXEC_STRING|EXEC_SUBST|EXEC_USECALC,calc_tolower},
       {"toupper",	EXEC_STRING|EXEC_SUBST|EXEC_USECALC,calc_toupper},
       {"translate",	EXEC_STRING|EXEC_USECALC,calc_translate},
