@@ -17,14 +17,6 @@
 	/* line input / output / translation routines
 	 * and error routines */
 
-	/* max number of lines in a work file */
-	/* Limit for datafield cache */
-#define LINE_LIMIT 16384
-	/* size of cached datafields */
-#define DATAFIELD_LIMIT 16384
-
-	/* Limit for any data working files. */
-int WORKFILE_LIMIT=512*1024;
 int is_class_module=0;
 
 int trusted_module(void);
