@@ -258,8 +258,8 @@ int check_session(void)
     }
     m_file.linepointer=3;
     wgetline(vbuf,MAX_LINELEN,&m_file); /* stored user_agent */
-    p=getenv("HTTP_USER_AGENT"); if(p==NULL) p="";
-    if(strcmp(vbuf+strlen("HTTP_USER_AGENT="),p)!=0) bad_ident();
+/*    p=getenv("HTTP_USER_AGENT"); if(p==NULL) p="";
+    if(strcmp(vbuf+strlen("HTTP_USER_AGENT="),p)!=0) bad_ident(); */
     m_file.linepointer=HEADER_VAR_NO;
     pl=strlen(var_prefix);i=-1;
     while(wgetline(tbuf,MAX_LINELEN,&m_file)!=EOF) {
