@@ -61,6 +61,9 @@ int defined_var_total;
 WORKING_FILE m_file,svar_file,mcache[MAX_MCACHE];
 int mcachecnt;
 
+	/* Limit for any data working files. */
+int WORKFILE_LIMIT=2048*1024;
+
 	/* whether the user has defined language */
 int user_lang=0;
 
