@@ -44,12 +44,18 @@
 	/* max number of sheets; not modifiable */
 #define MAX_SHEETS 64
 	/* max length of data files: records, activities, definitions. */
-#define MAX_FILELEN (512*1024-1)
+#define MAX_FILELEN (2048*1024-1)
 	/* max number of filewrite calls in one request */
 #define MAX_FWRITE 20
 	/* max total size of filewrite in one request */
 #define MAX_FWRITE_SIZE (64*1024)
 
+	/* max number of lines in a work file */
+	/* Limit for datafield cache */
+#define LINE_LIMIT 16384
+	/* size of cached datafields */
+#define DATAFIELD_LIMIT 16384
+
 	/* Define current version of the server here */
 #define wims_version PACKAGE_VERSION
 #ifdef VERSION_DATE
